@@ -1,5 +1,5 @@
 package HackaMol::X::Vina;
-
+$HackaMol::X::Vina::VERSION = '0.011';
 #ABSTRACT: HackaMol extension for running Autodock Vina
 use Moose;
 use MooseX::StrictConstructor;
@@ -11,7 +11,7 @@ use File::chdir;
 use namespace::autoclean;
 use Carp;
 
-with qw(HackaMol::X::ExtensionRole);
+with qw(HackaMol::X::Roles::ExtensionRole);
 
 has $_ => ( 
             is        => 'rw', 
@@ -188,7 +188,7 @@ HackaMol::X::Vina - HackaMol extension for running Autodock Vina
 
 =head1 VERSION
 
-version 0.01
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -267,11 +267,11 @@ This method takes no arguments; it returns, as a scalar, the input constructed f
 
 =head2 map_input
 
-provided by L<HackaMol::X::ExtensionRole>. Writes the configuration file for Vina. See dock and dock_mol methods.
+provided by L<HackaMol::X::Roles::ExtensionRole>. Writes the configuration file for Vina. See dock and dock_mol methods.
 
 =head2 map_output
 
-provided by L<HackaMol::X::ExtensionRole>. By default, this method returns the docking scores as an array.
+provided by L<HackaMol::X::Roles::ExtensionRole>. By default, this method returns the docking scores as an array.
 
 =head2 dock_mol
 
@@ -285,11 +285,11 @@ this method is similar to dock_mol, but returns only the scores.
 
 =head2 mol 
 
-isa L<HackaMol::Molecule> object that is 'ro' and provided by L<HackaMol::X::ExtensionRole>.  
+isa L<HackaMol::Molecule> object that is 'ro' and provided by L<HackaMol::X::Roles::ExtensionRole>.  
 
 =head2 map_in map_out 
 
-these attributes are 'ro' CodeRefs that can be adjusted in a given instance of a class. These are provided by L<HackaMol::X::ExtensionRole>.  Setting the map_in and map_out attributes are for advanced use.  Defaults are provided that are used in the map_input and map_output methods.
+these attributes are 'ro' CodeRefs that can be adjusted in a given instance of a class. These are provided by L<HackaMol::X::Roles::ExtensionRole>.  Setting the map_in and map_out attributes are for advanced use.  Defaults are provided that are used in the map_input and map_output methods.
 
 =head2 receptor ligand 
 
@@ -368,7 +368,7 @@ L<HackaMol>
 
 =item *
 
-L<HackaMol::X::ExtensionRole>
+L<HackaMol::X::Roles::ExtensionRole>
 
 =item *
 
@@ -404,13 +404,13 @@ L<Open Babel | http://openbabel.org>
 
 =over 4
 
-=item * L<HackaMol::ExeRole>
+=item * L<HackaMol::Roles::ExeRole>
 
-=item * L<HackaMol::ExeRole|HackaMol::PathRole>
+=item * L<HackaMol::Roles::ExeRole|HackaMol::Roles::PathRole>
 
-=item * L<HackaMol::PathRole>
+=item * L<HackaMol::Roles::PathRole>
 
-=item * L<HackaMol::X::ExtensionRole>
+=item * L<HackaMol::X::Roles::ExtensionRole>
 
 =back
 
